# Plugin management logic.
#
# Copyright (C) 2010 Sopra Steria Group (movalys.support@soprasteria.com)

# This file is part of Movalys MDK.
# Movalys MDK is free software: you can redistribute it and/or modify
# it under the terms of the GNU Lesser General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
# Movalys MDK is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
# GNU Lesser General Public License for more details.
# You should have received a copy of the GNU Lesser General Public License
# along with Movalys MDK. If not, see <http://www.gnu.org/licenses />.

require 'set'

# :nodoc: namespace
module MFXcode
  

# Plugin management logic.
module Plugins

  def self.all
    plugin_dir = File.join(File.dirname(__FILE__), '..')
    plugins = Dir.entries(plugin_dir).select { |entry|
      /^[^_].*\.rb$/ =~ entry 
    }.map { |entry| entry[0..-4] }
    return Set.new(plugins)
  end 
  
  def self.require_all
    all.each { |plugin| self.require plugin }
  end
  
  def self.require(plugin_name)
    Kernel.require "mfxcode/plugins/#{plugin_name}.rb"
  end
  
  def self.get(plugin_name)
    self.require plugin_name
    Plugins.const_get(plugin_name.capitalize).new
  end
  
  def self.run(plugin_name, args)
    self.get(plugin_name).run args
  end
  
  def self.help(plugin_name)
    self.get(plugin_name).help
  end
end  # module MFXcode::Plugins

end  # namespace MFXcode
